# -*- coding: utf-8 -*-
# file: tex_utils.py
# time: 2:47 2022/12/30 
# author: yangheng <hy345@exeter.ac.uk>
# github: https://github.com/yangheng95
# huggingface: https://huggingface.co/yangheng
# google scholar: https://scholar.google.com/citations?user=NPq5a_0AAAAJ&hl=en
# Copyright (C) 2021. All Rights Reserved.
import os.path
import re
from itertools import zip_longest
from pathlib import Path
from typing import Union


def extract_tables_from_tex(tex_src_or_file_path):
    """Extract tables from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of tables.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    tables = re.findall(r'table.*?}', tex, re.DOTALL)
    return tables


def extract_x_label_from_tex(tex_src_or_file_path):
    """Extract x label from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of x label.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    x_labels = re.findall(r'xlabel.*?},', tex, re.DOTALL)
    return x_labels[0] if x_labels else None


def extract_y_label_from_tex(tex_src_or_file_path):
    """Extract y label from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of y label.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    y_labels = re.findall(r'ylabel.*?},', tex, re.DOTALL)
    return y_labels[0] if y_labels else None


def extract_x_tick_from_tex(tex_src_or_file_path):
    """Extract x tick from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of x tick.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    x_ticks = re.findall(r'xtick.*?}', tex, re.DOTALL)
    return x_ticks


def extract_y_tick_from_tex(tex_src_or_file_path):
    """Extract y tick from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of y tick.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    y_ticks = re.findall(r'ytick.*?}', tex, re.DOTALL)
    return y_ticks


def extract_legend_from_tex(tex_src_or_file_path):
    """Extract legend from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of legend.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    legends = re.findall(r'\\addlegendentry.*?}', tex, re.DOTALL)
    if legends:
        for i, legend in enumerate(legends):
            legends[i] = legend.replace('\\addlegendentry{', '').replace('}', '')
    if not legends:
        legends = re.findall(r'legend entries.*?}', tex, re.DOTALL)
        if not legends:
            return []
        legends = re.findall(r'{.*?}', legends[0], re.DOTALL)[0][1:-1].split(',')
    return legends


def remove_legend_from_tex(tex_src_or_file_path):
    """Remove legend from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of legend.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    legends = re.findall(r'\\addlegendentry.*?}', tex, re.DOTALL)
    if legends:
        for i, legend in enumerate(legends):
            tex = tex.replace(legend, '')
    if not legends:
        legends = re.findall('legend entries.*?},.*?\n', tex, re.DOTALL)
        if legends:
            for i, legend in enumerate(legends):
                tex = tex.replace(legend, '')
    return tex


def extract_style_from_tex(tex_src_or_file_path):
    """Extract style from tex file.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of style.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    styles = re.findall(r'\\begin{axis.*?,.*?\]', tex, re.DOTALL)
    for i, style in enumerate(styles):
        if ',\n]' not in styles[i]:
            styles[i] = styles[i].replace('\n]', ',\n]')
    return styles[0]


def preprocess_style(tex_src_or_file_path):
    """Preprocess style.

    Args:
        tex_src_or_file_path (str): tex file path.

    Returns:
        list: list of style.
    """
    import re
    if os.path.exists(tex_src_or_file_path):
        with open(tex_src_or_file_path, 'r') as f:
            tex = f.read()
    else:
        tex = tex_src_or_file_path
    styles = re.findall(r'\\begin{axis.*?,.*?\]', tex, re.DOTALL)
    assert len(styles) == 1
    for i, style in enumerate(styles):
        while '\n ' in styles[i]:
            styles[i] = styles[i].replace('\n ', '\n')
        while ' \n' in styles[i]:
            styles[i] = styles[i].replace(' \n', '\n')
        while '\t' in styles[i]:
            styles[i] = styles[i].replace('\t', '')

        if ',\n]' not in styles[i]:
            styles[i] = styles[i].replace('\n]', ',\n]')
        tex = tex.replace(style, styles[i])
    return tex


def reformat_tikz_format_for_colalab(template: Union[str, Path],
                                     tex_src_to_format: Union[str, Path],
                                     output_path: Union[str, Path] = None,
                                     style_settings: dict = None,
                                     **kwargs
                                     ):
    """Reformat tikz format.

    Args:
        template (str): template.
        tex_src_to_format (str): tex src to format.
        output_path (Path): output path.
        style_settings (dict): style settings.

    Returns:
        str: formatted tex src.

    """
    _template = template[:]
    _template = preprocess_style(_template)
    for new_table, old_table in zip_longest(extract_tables_from_tex(tex_src_to_format),
                                            extract_tables_from_tex(_template)):
        if old_table and new_table:
            _template = _template.replace(old_table, new_table, 1)
        elif old_table and not new_table:
            _template = _template.replace(old_table, '', 1)
        else:
            pass

    new_x_label = extract_x_label_from_tex(tex_src_to_format)
    old_x_label = extract_x_label_from_tex(_template)
    if old_x_label and new_x_label:
        _template = _template.replace(old_x_label, new_x_label, 1)
    elif old_x_label and not new_x_label:
        _template = _template.replace(old_x_label, '', 1)
    elif new_x_label:
        style_settings['xlabel'] = new_x_label.replace('xlabel=', '').replace(',', '')  # replace not available, waiting for style setting

    new_y_label = extract_y_label_from_tex(tex_src_to_format)
    old_y_label = extract_y_label_from_tex(_template)
    if old_y_label and new_y_label:
        _template = _template.replace(old_y_label, new_y_label, 1)
    elif old_y_label and not new_y_label:
        _template = _template.replace(old_y_label, '', 1)
    elif new_y_label:
        style_settings['ylabel'] = new_y_label.replace('ylabel=', '').replace(',', '')  # replace not available, waiting for style setting


    for new_legend, old_legend in zip_longest(extract_legend_from_tex(tex_src_to_format),
                                              extract_legend_from_tex(_template)):
        if old_legend and new_legend:
            _template = _template.replace(old_legend, new_legend, 1)
        elif old_legend and not new_legend:
            _template = _template.replace(old_legend, '', 1)
            while ',,' in _template:
                _template = _template.replace(',,', ',')
        else:
            style_settings['legend'] = new_legend

    for k, v in style_settings.items():
        _template = _template.replace(extract_style_from_tex(_template),
                                      extract_style_from_tex(_template).replace(']', '{}={},\n]'.format(k, v)), 1)

    if kwargs.get('no_legend', False):
        _template = remove_legend_from_tex(_template)

    if os.path.exists(tex_src_to_format):
        output_path = os.path.join(Path(tex_src_to_format), '.tex')

    with open(os.path.join(output_path), 'w') as f:
        f.write(_template)
    os.system('pdflatex %s %s' % (output_path, output_path))
    os.system('pdfcrop %s %s' % (output_path.replace('.tex', '.pdf'), output_path.replace('.tex', '.pdf')))

    return _template


if __name__ == '__main__':
    tex_src_template = r"""
        \documentclass{article}
        \usepackage{pgfplots}
        \usepackage{tikz}
        \usetikzlibrary{intersections}
        \usepackage{helvet}
        \usepackage[eulergreek]{sansmath}
        
        \begin{document}
        \pagestyle{empty}
        
        \pgfplotsset{every axis/.append style={
        font = \Large,
        grid = major,
        xlabel = {index},
        ylabel = {R-HV},
        %ymode  = log,
        thick,
        %xmin = 1,
        %xmax = 10,
        %ymin = 3.6,
        %ymax = 4.2,
        line width = 1pt,
        tick style = {line width = 0.8pt}}}
        
        \begin{tikzpicture}
            \begin{axis}[
                xtick = {1,...,10},
                xticklabels = {0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1},
                legend pos = south east,
                legend cell align=left,
                legend style={font=\footnotesize},
                legend entries = {r-MOEA/D-STM, R-NSGA-II, g-NSGA-II, r-NSGA-II},
            ]
            \addplot[black, mark = *, mark size = 2.5pt] table[x index = 0, y index = 1] {data/delta_hv.dat};
            \addplot[green, mark = square*, mark size = 2.5pt] table[x index = 0, y index = 2] {data/delta_hv.dat};
            \addplot[red, mark = triangle*, mark size = 2.5pt] table[x index = 0, y index = 3] {data/delta_hv.dat}; 
            \end{axis}
        \end{tikzpicture}
        
        \end{document}
            """

    tex_src_data = r"""
    % This file was created with tikzplotlib v0.10.1.
    \begin{tikzpicture}
    
    \definecolor{cyan}{RGB}{0,255,255}
    \definecolor{darkgray176}{RGB}{176,176,176}
    \definecolor{lightgray204}{RGB}{204,204,204}
    \definecolor{lightgreen}{RGB}{144,238,144}
    
    \begin{axis}[
    legend cell align={left},
    legend style={
      fill opacity=0.8,
      draw opacity=1,
      text opacity=1,
      at={(0.03,0.03)},
      anchor=south west,
      draw=lightgray204
    },
    tick align=outside,
    tick pos=left,
    x grid style={darkgray176},
    xlabel={\(\displaystyle \Delta_{adv}\): -0.28\% \(\displaystyle \Delta_{rep}\): 0.79\%},
    xmajorgrids,
    xmin=-1.1004173874855, xmax=1.10072947740555,
    xtick style={color=black},
    y grid style={darkgray176},
    ylabel={Amazon (PWWS)},
    ymajorgrids,
    ymin=0, ymax=1,
    ytick style={color=black}
    ]
    \addplot [thick, lightgreen, const plot mark left, mark=*, mark size=3, mark options={solid}]
    table {%
    -inf 0
    0.999347925186157 0.002
    0.999359369277954 0.004
    0.999406099319458 0.006
    0.999421119689941 0.008
    0.999427080154419 0.01
    0.999427080154419 0.012
    0.999427080154419 0.014
    0.999430894851685 0.016
    0.999430894851685 0.018
    0.999430894851685 0.02
    0.999439239501953 0.022
    0.999456644058228 0.024
    0.999456644058228 0.026
    0.99946141242981 0.028
    0.999483346939087 0.03
    0.999483346939087 0.032
    0.99949836730957 0.034
    0.999504327774048 0.036
    0.999504566192627 0.038
    0.999510049819946 0.04
    0.999510288238525 0.042
    0.999510288238525 0.044
    0.999510288238525 0.046
    0.999511003494263 0.048
    0.999511003494263 0.05
    0.99951958656311 0.052
    0.999527454376221 0.054
    0.999539613723755 0.056
    0.999539613723755 0.058
    0.99956750869751 0.06
    0.99956750869751 0.062
    0.99956750869751 0.064
    0.999569177627563 0.066
    0.999576568603516 0.068
    0.999582529067993 0.07
    0.999582529067993 0.072
    0.999585390090942 0.074
    0.999598026275635 0.076
    0.999599695205688 0.078
    0.999628067016602 0.08
    0.999628067016602 0.082
    0.999630928039551 0.084
    0.99963116645813 0.086
    0.99963116645813 0.088
    0.99963116645813 0.09
    0.999637603759766 0.092
    0.999637603759766 0.094
    0.999637603759766 0.096
    0.999637603759766 0.098
    0.999638795852661 0.1
    0.999638855457306 0.102
    0.999646186828613 0.104
    0.999646186828613 0.106
    0.999661684036255 0.108
    0.999661684036255 0.11
    0.999661684036255 0.112
    0.999661684036255 0.114
    0.999663591384888 0.116
    0.999663591384888 0.118
    0.999679803848267 0.12
    0.999679803848267 0.122
    0.999679803848267 0.124
    0.999683856964111 0.126
    0.999696969985962 0.128
    0.999696969985962 0.13
    0.999696969985962 0.132
    0.999699831008911 0.134
    0.999708652496338 0.136
    0.999708652496338 0.138
    0.999708652496338 0.14
    0.999711811542511 0.142
    0.999715089797974 0.144
    0.999724626541138 0.146
    0.999729633331299 0.148
    0.999731302261353 0.15
    0.999731302261353 0.152
    0.999731302261353 0.154
    0.999731302261353 0.156
    0.999731302261353 0.158
    0.999731302261353 0.16
    0.999741792678833 0.162
    0.999741792678833 0.164
    0.999741792678833 0.166
    0.999742984771729 0.168
    0.99974536895752 0.17
    0.99974536895752 0.172
    0.99974536895752 0.174
    0.999758243560791 0.176
    0.999758243560791 0.178
    0.999758243560791 0.18
    0.999760150909424 0.182
    0.999761819839478 0.184
    0.999761819839478 0.186
    0.999761819839478 0.188
    0.999761819839478 0.19
    0.999761819839478 0.192
    0.99976658821106 0.194
    0.999772071838379 0.196
    0.999772071838379 0.198
    0.999775171279907 0.2
    0.999780654907227 0.202
    0.999780654907227 0.204
    0.999780654907227 0.206
    0.999780654907227 0.208
    0.999780654907227 0.21
    0.999786376953125 0.212
    0.999786853790283 0.214
    0.999786853790283 0.216
    0.999788284301758 0.218
    0.999788284301758 0.22
    0.999790668487549 0.222
    0.999790668487549 0.224
    0.999790668487549 0.226
    0.999794006347656 0.228
    0.999794006347656 0.23
    0.99979829788208 0.232
    0.999802827835083 0.234
    0.999802827835083 0.236
    0.999802827835083 0.238
    0.999802827835083 0.24
    0.999802827835083 0.242
    0.999802827835083 0.244
    0.99980354309082 0.246
    0.999809741973877 0.248
    0.999809741973877 0.25
    0.99981689453125 0.252
    0.99981689453125 0.254
    0.99981689453125 0.256
    0.999822854995728 0.258
    0.999822854995728 0.26
    0.999822854995728 0.262
    0.999822854995728 0.264
    0.99982476234436 0.266
    0.99982476234436 0.268
    0.999825000762939 0.27
    0.999833345413208 0.272
    0.999833345413208 0.274
    0.999834060668945 0.276
    0.999834060668945 0.278
    0.999834060668945 0.28
    0.999836206436157 0.282
    0.999836206436157 0.284
    0.999840021133423 0.286
    0.999840021133423 0.288
    0.999840021133423 0.29
    0.999840021133423 0.292
    0.999844074249268 0.294
    0.999844074249268 0.296
    0.999844074249268 0.298
    0.999844074249268 0.3
    0.999844074249268 0.302
    0.999848365783691 0.304
    0.999848365783691 0.306
    0.999848365783691 0.308
    0.999853610992432 0.31
    0.999853610992432 0.312
    0.999855041503906 0.314
    0.999855041503906 0.316
    0.999855041503906 0.318
    0.999855041503906 0.32
    0.999855101108551 0.322
    0.999861240386963 0.324
    0.999861240386963 0.326
    0.999861240386963 0.328
    0.999861240386963 0.33
    0.999866962432861 0.332
    0.999866962432861 0.334
    0.999871492385864 0.336
    0.999878168106079 0.338
    0.999878168106079 0.34
    0.999878168106079 0.342
    0.999878168106079 0.344
    0.999879837036133 0.346
    0.999879837036133 0.348
    0.999879837036133 0.35
    0.99988865852356 0.352
    0.99988865852356 0.354
    0.999893665313721 0.356
    0.999893665313721 0.358
    0.999893665313721 0.36
    0.999901294708252 0.362
    0.999904870986938 0.364
    0.999904870986938 0.366
    0.999904870986938 0.368
    0.999904870986938 0.37
    0.999904870986938 0.372
    0.999904870986938 0.374
    0.999908447265625 0.376
    0.999908447265625 0.378
    0.999908447265625 0.38
    0.999908447265625 0.382
    0.999908447265625 0.384
    0.999908447265625 0.386
    0.999917268753052 0.388
    0.999917268753052 0.39
    0.999917268753052 0.392
    0.999924182891846 0.394
    0.999924182891846 0.396
    0.999927520751953 0.398
    0.999927520751953 0.4
    0.999927520751953 0.402
    0.999927520751953 0.404
    0.999935626983643 0.406
    0.999940872192383 0.408
    0.999940872192383 0.41
    0.999940872192383 0.412
    0.999940872192383 0.414
    0.999940872192383 0.416
    0.999940872192383 0.418
    0.999943017959595 0.42
    0.999951362609863 0.422
    0.999951362609863 0.424
    0.999953508377075 0.426
    0.999955177307129 0.428
    0.999955177307129 0.43
    0.999955177307129 0.432
    0.999955177307129 0.434
    0.999955177307129 0.436
    0.999955177307129 0.438
    0.999955177307129 0.44
    0.999957323074341 0.442
    0.999957323074341 0.444
    0.999957323074341 0.446
    0.999958515167236 0.448
    0.999958515167236 0.45
    0.999958515167236 0.452
    0.999968767166138 0.454
    0.999977111816406 0.456
    0.999977111816406 0.458
    0.999977111816406 0.46
    0.999977111816406 0.462
    0.999987840652466 0.464
    0.999987840652466 0.466
    0.999996662139893 0.468
    0.999998331069946 0.47
    0.999998331069946 0.472
    0.999998331069946 0.474
    0.999998331069946 0.476
    0.999998331069946 0.478
    1.00000238418579 0.48
    1.00000238418579 0.482
    1.00000238418579 0.484
    1.00000238418579 0.486
    1.00000238418579 0.488
    1.00000238418579 0.49
    1.00000238418579 0.492
    1.00000238418579 0.494
    1.00000238418579 0.496
    1.00000238418579 0.498
    1.00000238418579 0.5
    1.00001001358032 0.502
    1.00001001358032 0.504
    1.0000171661377 0.506
    1.0000171661377 0.508
    1.0000171661377 0.51
    1.0000171661377 0.512
    1.0000171661377 0.514
    1.0000171661377 0.516
    1.0000171661377 0.518
    1.0000171661377 0.52
    1.0000171661377 0.522
    1.0000171661377 0.524
    1.0000171661377 0.526
    1.0000171661377 0.528
    1.0000171661377 0.53
    1.0000171661377 0.532
    1.0000171661377 0.534
    1.00001931190491 0.536
    1.00001931190491 0.538
    1.00001931190491 0.54
    1.00003862380981 0.542
    1.00003862380981 0.544
    1.00003862380981 0.546
    1.00003862380981 0.548
    1.00003862380981 0.55
    1.00003862380981 0.552
    1.00003862380981 0.554
    1.00003862380981 0.556
    1.00004005432129 0.558
    1.00004005432129 0.56
    1.00004005432129 0.562
    1.00004029273987 0.564
    1.00004029273987 0.566
    1.00004243850708 0.568
    1.00004243850708 0.57
    1.00004243850708 0.572
    1.0000536441803 0.574
    1.0000536441803 0.576
    1.00005435943604 0.578
    1.00005567073822 0.58
    1.00006103515625 0.582
    1.00006103515625 0.584
    1.00006103515625 0.586
    1.00006103515625 0.588
    1.00006103515625 0.59
    1.00006103515625 0.592
    1.00006103515625 0.594
    1.00006103515625 0.596
    1.00006103515625 0.598
    1.00006580352783 0.6
    1.00006580352783 0.602
    1.00006580352783 0.604
    1.00006580352783 0.606
    1.00006580352783 0.608
    1.00006699562073 0.61
    1.00007176399231 0.612
    1.00007176399231 0.614
    1.00007820129395 0.616
    1.00007820129395 0.618
    1.00007820129395 0.62
    1.00007939338684 0.622
    1.00008010864258 0.624
    1.00008320808411 0.626
    1.00008320808411 0.628
    1.00008320808411 0.63
    1.000084400177 0.632
    1.000084400177 0.634
    1.000084400177 0.636
    1.000084400177 0.638
    1.000084400177 0.64
    1.000084400177 0.642
    1.00008606910706 0.644
    1.00008606910706 0.646
    1.00008606910706 0.648
    1.00008606910706 0.65
    1.00010776519775 0.652
    1.00010776519775 0.654
    1.00010871887207 0.656
    1.00010871887207 0.658
    1.00010871887207 0.66
    1.00010871887207 0.662
    1.00010871887207 0.664
    1.00010871887207 0.666
    1.00010871887207 0.668
    1.00010871887207 0.67
    1.00012254714966 0.672
    1.00012254714966 0.674
    1.00012254714966 0.676
    1.00012707710266 0.678
    1.00012898445129 0.68
    1.00013399124146 0.682
    1.00013399124146 0.684
    1.00013399124146 0.686
    1.00013732910156 0.688
    1.00013732910156 0.69
    1.00015377998352 0.692
    1.00015377998352 0.694
    1.00015377998352 0.696
    1.00015377998352 0.698
    1.00015377998352 0.7
    1.00015497207642 0.702
    1.00015497207642 0.704
    1.00015497207642 0.706
    1.00015497207642 0.708
    1.00015664100647 0.71
    1.00015664100647 0.712
    1.00016021728516 0.714
    1.00016021728516 0.716
    1.00016021728516 0.718
    1.00016021728516 0.72
    1.00016021728516 0.722
    1.00016021728516 0.724
    1.00016021728516 0.726
    1.00016021728516 0.728
    1.00016021728516 0.73
    1.00016021728516 0.732
    1.00016617774963 0.734
    1.00016617774963 0.736
    1.0001802444458 0.738
    1.0001802444458 0.74
    1.00018739700317 0.742
    1.00018739700317 0.744
    1.00019693374634 0.746
    1.00020480155945 0.748
    1.00020837783813 0.75
    1.00020837783813 0.752
    1.00021553039551 0.754
    1.00021553039551 0.756
    1.00021553039551 0.758
    1.00021553039551 0.76
    1.00021553039551 0.762
    1.00021553039551 0.764
    1.00021553039551 0.766
    1.00021767616272 0.768
    1.00022172927856 0.77
    1.0002224445343 0.772
    1.0002224445343 0.774
    1.0002224445343 0.776
    1.00022554397583 0.778
    1.00022745132446 0.78
    1.00022745132446 0.782
    1.00022745132446 0.784
    1.0002326965332 0.786
    1.0002326965332 0.788
    1.0002326965332 0.79
    1.0002338886261 0.792
    1.00023889541626 0.794
    1.00023889541626 0.796
    1.00023889541626 0.798
    1.00024247169495 0.8
    1.00024247169495 0.802
    1.00024247169495 0.804
    1.00024247169495 0.806
    1.00024461746216 0.808
    1.00024461746216 0.81
    1.00024461746216 0.812
    1.00024461746216 0.814
    1.00025677680969 0.816
    1.00025677680969 0.818
    1.00026440620422 0.82
    1.00026631355286 0.822
    1.00027465820312 0.824
    1.00027465820312 0.826
    1.00027465820312 0.828
    1.00027465820312 0.83
    1.00027465820312 0.832
    1.00027465820312 0.834
    1.00027465820312 0.836
    1.00027894973755 0.838
    1.0002920627594 0.84
    1.0002920627594 0.842
    1.0002920627594 0.844
    1.00029611587524 0.846
    1.00029611587524 0.848
    1.00029850006104 0.85
    1.00030565261841 0.852
    1.00030565261841 0.854
    1.00030565261841 0.856
    1.00031137466431 0.858
    1.00031137466431 0.86
    1.00031137466431 0.862
    1.00031137466431 0.864
    1.00031137466431 0.866
    1.00031208992004 0.868
    1.00032925605774 0.87
    1.00033760070801 0.872
    1.00033760070801 0.874
    1.00033760070801 0.876
    1.00033760070801 0.878
    1.00033760070801 0.88
    1.00033760070801 0.882
    1.00033760070801 0.884
    1.00033760070801 0.886
    1.00034427642822 0.888
    1.00035905838013 0.89
    1.00035905838013 0.892
    1.00036263465881 0.894
    1.00036263465881 0.896
    1.00036263465881 0.898
    1.0003674030304 0.9
    1.00037050247192 0.902
    1.00037050247192 0.904
    1.00037050247192 0.906
    1.00037050247192 0.908
    1.00037050247192 0.91
    1.00037050247192 0.912
    1.00037384033203 0.914
    1.00039100646973 0.916
    1.00039100646973 0.918
    1.00039100646973 0.92
    1.00039100646973 0.922
    1.00040078163147 0.924
    1.00040435791016 0.926
    1.00040435791016 0.928
    1.00040435791016 0.93
    1.00040435791016 0.932
    1.00041627883911 0.934
    1.00041699409485 0.936
    1.00043916702271 0.938
    1.00043916702271 0.94
    1.00044870376587 0.942
    1.00046730041504 0.944
    1.00047159194946 0.946
    1.00047159194946 0.948
    1.00047159194946 0.95
    1.00047707557678 0.952
    1.00047707557678 0.954
    1.00049138069153 0.956
    1.00049138069153 0.958
    1.00049710273743 0.96
    1.00050663948059 0.962
    1.00050663948059 0.964
    1.00051140785217 0.966
    1.00051140785217 0.968
    1.00051212310791 0.97
    1.00051236152649 0.972
    1.00051999092102 0.974
    1.00052952766418 0.976
    1.0005464553833 0.978
    1.0005464553833 0.98
    1.00055146217346 0.982
    1.00056385993958 0.984
    1.00056385993958 0.986
    1.00058007240295 0.988
    1.00059151649475 0.99
    1.00060892105103 0.992
    1.00060892105103 0.994
    1.00064015388489 0.996
    1.0006582736969 0.998
    1.00067734718323 1
    };
    \addlegendentry{Natural Example}
    \addplot [thick, red, const plot mark left, mark=asterisk, mark size=3, mark options={solid}]
    table {%
    -inf 0
    -1.00033617019653 0.002
    -1.00026941299438 0.004
    -1.0001814365387 0.006
    -1.00017356872559 0.008
    -1.00016331672668 0.01
    -1.00011396408081 0.012
    -1.00008726119995 0.014
    -1.00006771087646 0.016
    -1.00002264976501 0.018
    -1.00000524520874 0.02
    -1.00000095367432 0.022
    -0.999991893768311 0.024
    -0.999935150146484 0.026
    -0.999898910522461 0.028
    -0.999894857406616 0.03
    -0.999856472015381 0.032
    -0.999851703643799 0.034
    -0.99984884262085 0.036
    -0.999839544296265 0.038
    -0.999822854995728 0.04
    -0.999789714813232 0.042
    -0.999782085418701 0.044
    -0.999778747558594 0.046
    -0.999767541885376 0.048
    -0.999767303466797 0.05
    -0.999738693237305 0.052
    -0.999706745147705 0.054
    -0.999689102172852 0.056
    -0.999686241149902 0.058
    -0.999686241149902 0.06
    -0.99968147277832 0.062
    -0.999674081802368 0.064
    -0.999673843383789 0.066
    -0.999650239944458 0.068
    -0.999632835388184 0.07
    -0.99960470199585 0.072
    -0.999600887298584 0.074
    -0.999584197998047 0.076
    -0.999577283859253 0.078
    -0.999576330184937 0.08
    -0.999569892883301 0.082
    -0.999564170837402 0.084
    -0.999550580978394 0.086
    -0.999503135681152 0.088
    -0.999450445175171 0.09
    -0.999439716339111 0.092
    -0.999414920806885 0.094
    -0.999412775039673 0.096
    -0.99936318397522 0.098
    -0.99936056137085 0.1
    -0.999316215515137 0.102
    -0.999265193939209 0.104
    -0.999185800552368 0.106
    -0.999156713485718 0.108
    -0.999151229858398 0.11
    -0.999135971069336 0.112
    -0.999098300933838 0.114
    -0.999074935913086 0.116
    -0.999068260192871 0.118
    -0.999063968658447 0.12
    -0.999037265777588 0.122
    -0.999031782150269 0.124
    -0.999031782150269 0.126
    -0.998999118804932 0.128
    -0.998994112014771 0.13
    -0.998934268951416 0.132
    -0.998908042907715 0.134
    -0.998857498168945 0.136
    -0.99876880645752 0.138
    -0.998644113540649 0.14
    -0.998594999313354 0.142
    -0.998523235321045 0.144
    -0.998489856719971 0.146
    -0.998394012451172 0.148
    -0.998382568359375 0.15
    -0.99836277961731 0.152
    -0.998235702514648 0.154
    -0.998155117034912 0.156
    -0.998081922531128 0.158
    -0.998001098632812 0.16
    -0.997910261154175 0.162
    -0.997868299484253 0.164
    -0.997765064239502 0.166
    -0.997743606567383 0.168
    -0.997674703598022 0.17
    -0.997599601745605 0.172
    -0.997576713562012 0.174
    -0.997572898864746 0.176
    -0.997550010681152 0.178
    -0.997438430786133 0.18
    -0.997421503067017 0.182
    -0.997416973114014 0.184
    -0.99738073348999 0.186
    -0.99735164642334 0.188
    -0.997321844100952 0.19
    -0.997300386428833 0.192
    -0.997185468673706 0.194
    -0.997170209884644 0.196
    -0.997153282165527 0.198
    -0.99712610244751 0.2
    -0.997076749801636 0.202
    -0.997052669525146 0.204
    -0.996986627578735 0.206
    -0.996984481811523 0.208
    -0.996728181838989 0.21
    -0.996604204177856 0.212
    -0.996603965759277 0.214
    -0.996589422225952 0.216
    -0.996572494506836 0.218
    -0.996465682983398 0.22
    -0.996450424194336 0.222
    -0.996363401412964 0.224
    -0.996307373046875 0.226
    -0.996295928955078 0.228
    -0.996226787567139 0.23
    -0.996204614639282 0.232
    -0.996165752410889 0.234
    -0.996041297912598 0.236
    -0.996015548706055 0.238
    -0.995633125305176 0.24
    -0.995621681213379 0.242
    -0.995509624481201 0.244
    -0.995440006256104 0.246
    -0.995417833328247 0.248
    -0.995289087295532 0.25
    -0.9952552318573 0.252
    -0.995051145553589 0.254
    -0.994930028915405 0.256
    -0.994925022125244 0.258
    -0.994900941848755 0.26
    -0.994796752929688 0.262
    -0.994678020477295 0.264
    -0.99463415145874 0.266
    -0.994613885879517 0.268
    -0.994430541992188 0.27
    -0.994194984436035 0.272
    -0.994012832641602 0.274
    -0.993898391723633 0.276
    -0.993829965591431 0.278
    -0.993772745132446 0.28
    -0.993731498718262 0.282
    -0.993666648864746 0.284
    -0.993619441986084 0.286
    -0.993505477905273 0.288
    -0.993480443954468 0.29
    -0.993452072143555 0.292
    -0.993419885635376 0.294
    -0.993308305740356 0.296
    -0.993175745010376 0.298
    -0.993079662322998 0.3
    -0.993030548095703 0.302
    -0.993003129959106 0.304
    -0.992925643920898 0.306
    -0.992888927459717 0.308
    -0.992878913879395 0.31
    -0.992812156677246 0.312
    -0.992766857147217 0.314
    -0.992749214172363 0.316
    -0.992645263671875 0.318
    -0.992639064788818 0.32
    -0.992518424987793 0.322
    -0.992339134216309 0.324
    -0.992278099060059 0.326
    -0.992122173309326 0.328
    -0.991827964782715 0.33
    -0.991596698760986 0.332
    -0.99150562286377 0.334
    -0.991409778594971 0.336
    -0.991346836090088 0.338
    -0.990509748458862 0.34
    -0.9904625415802 0.342
    -0.989520072937012 0.344
    -0.989441394805908 0.346
    -0.988615036010742 0.348
    -0.98851203918457 0.35
    -0.988496541976929 0.352
    -0.988393306732178 0.354
    -0.988069534301758 0.356
    -0.98799991607666 0.358
    -0.987672805786133 0.36
    -0.986733198165894 0.362
    -0.986415386199951 0.364
    -0.986246109008789 0.366
    -0.9860999584198 0.368
    -0.985931158065796 0.37
    -0.985378623008728 0.372
    -0.984886169433594 0.374
    -0.984797239303589 0.376
    -0.984673261642456 0.378
    -0.98401403427124 0.38
    -0.983756303787231 0.382
    -0.983052015304565 0.384
    -0.98294472694397 0.386
    -0.982931852340698 0.388
    -0.982330799102783 0.39
    -0.981707572937012 0.392
    -0.981329679489136 0.394
    -0.9798583984375 0.396
    -0.979823589324951 0.398
    -0.979520797729492 0.4
    -0.978835344314575 0.402
    -0.978607654571533 0.404
    -0.977714538574219 0.406
    -0.977442264556885 0.408
    -0.977323293685913 0.41
    -0.977144718170166 0.412
    -0.977035760879517 0.414
    -0.975795030593872 0.416
    -0.975740432739258 0.418
    -0.975578784942627 0.42
    -0.975239038467407 0.422
    -0.974738597869873 0.424
    -0.974299192428589 0.426
    -0.972641825675964 0.428
    -0.972344875335693 0.43
    -0.972218990325928 0.432
    -0.971032381057739 0.434
    -0.970771312713623 0.436
    -0.9707350730896 0.438
    -0.969852566719055 0.44
    -0.969359159469604 0.442
    -0.969011664390564 0.444
    -0.967830181121826 0.446
    -0.966488838195801 0.448
    -0.966487526893616 0.45
    -0.966480255126953 0.452
    -0.962469696998596 0.454
    -0.960161685943604 0.456
    -0.958609104156494 0.458
    -0.95569384098053 0.46
    -0.955397248268127 0.462
    -0.952820777893066 0.464
    -0.952591180801392 0.466
    -0.951206088066101 0.468
    -0.947263836860657 0.47
    -0.946457862854004 0.472
    -0.946107625961304 0.474
    -0.945885539054871 0.476
    -0.942867398262024 0.478
    -0.942409038543701 0.48
    -0.941036939620972 0.482
    -0.93947696685791 0.484
    -0.938248634338379 0.486
    -0.937481880187988 0.488
    -0.935258507728577 0.49
    -0.935070514678955 0.492
    -0.934408903121948 0.494
    -0.934312224388123 0.496
    -0.933760166168213 0.498
    -0.932963371276855 0.5
    -0.925989627838135 0.502
    -0.922267198562622 0.504
    -0.921541690826416 0.506
    -0.920448541641235 0.508
    -0.920317649841309 0.51
    -0.918228149414062 0.512
    -0.915627717971802 0.514
    -0.913655757904053 0.516
    -0.906991958618164 0.518
    -0.901286959648132 0.52
    -0.892589092254639 0.522
    -0.885220885276794 0.524
    -0.878341197967529 0.526
    -0.877745628356934 0.528
    -0.877532005310059 0.53
    -0.877417325973511 0.532
    -0.874546051025391 0.534
    -0.868667840957642 0.536
    -0.857182502746582 0.538
    -0.851161122322083 0.54
    -0.838860034942627 0.542
    -0.831406712532043 0.544
    -0.829358696937561 0.546
    -0.819668412208557 0.548
    -0.815654754638672 0.55
    -0.815131664276123 0.552
    -0.808456897735596 0.554
    -0.803481638431549 0.556
    -0.799971461296082 0.558
    -0.779677927494049 0.56
    -0.760517835617065 0.562
    -0.751208484172821 0.564
    -0.731746971607208 0.566
    -0.730731606483459 0.568
    -0.714053809642792 0.57
    -0.710506439208984 0.572
    -0.696980655193329 0.574
    -0.686998128890991 0.576
    -0.683349132537842 0.578
    -0.677739143371582 0.58
    -0.664142370223999 0.582
    -0.663658618927002 0.584
    -0.620241284370422 0.586
    -0.595995187759399 0.588
    -0.594964027404785 0.59
    -0.592445611953735 0.592
    -0.584408521652222 0.594
    -0.577517747879028 0.596
    -0.573551893234253 0.598
    -0.564612805843353 0.6
    -0.525273323059082 0.602
    -0.488047122955322 0.604
    -0.473804950714111 0.606
    -0.421915769577026 0.608
    -0.41248083114624 0.61
    -0.358577013015747 0.612
    -0.356002330780029 0.614
    -0.354507446289062 0.616
    -0.349872589111328 0.618
    -0.331448435783386 0.62
    -0.329147338867188 0.622
    -0.322673678398132 0.624
    -0.298099994659424 0.626
    -0.279940366744995 0.628
    -0.238296985626221 0.63
    -0.232150316238403 0.632
    -0.227203130722046 0.634
    -0.200084209442139 0.636
    -0.167552947998047 0.638
    -0.164852142333984 0.64
    -0.128180980682373 0.642
    -0.103843450546265 0.644
    -0.0842676162719727 0.646
    -0.0583164691925049 0.648
    -0.0525321960449219 0.65
    -0.0321016311645508 0.652
    -0.0096890926361084 0.654
    0.0424873828887939 0.656
    0.118237018585205 0.658
    0.169753551483154 0.66
    0.19149112701416 0.662
    0.236606597900391 0.664
    0.311118364334106 0.666
    0.324140548706055 0.668
    0.351671934127808 0.67
    0.360190153121948 0.672
    0.369344472885132 0.674
    0.431066989898682 0.676
    0.44743549823761 0.678
    0.454787254333496 0.68
    0.469649434089661 0.682
    0.533442378044128 0.684
    0.552994787693024 0.686
    0.559674263000488 0.688
    0.593249320983887 0.69
    0.624042749404907 0.692
    0.642935752868652 0.694
    0.704081833362579 0.696
    0.712010324001312 0.698
    0.721238493919373 0.7
    0.729764878749847 0.702
    0.736081123352051 0.704
    0.737093567848206 0.706
    0.742570519447327 0.708
    0.74304872751236 0.71
    0.786118745803833 0.712
    0.789572238922119 0.714
    0.80972945690155 0.716
    0.828140735626221 0.718
    0.832363843917847 0.72
    0.833651065826416 0.722
    0.83539891242981 0.724
    0.842288970947266 0.726
    0.846309304237366 0.728
    0.876617431640625 0.73
    0.877224922180176 0.732
    0.881672501564026 0.734
    0.887769341468811 0.736
    0.895654678344727 0.738
    0.903908491134644 0.74
    0.906551361083984 0.742
    0.907120227813721 0.744
    0.912099838256836 0.746
    0.91324782371521 0.748
    0.915554642677307 0.75
    0.922109603881836 0.752
    0.922157764434814 0.754
    0.925298690795898 0.756
    0.935746669769287 0.758
    0.945703029632568 0.76
    0.947110176086426 0.762
    0.950698256492615 0.764
    0.953118562698364 0.766
    0.954836368560791 0.768
    0.958912372589111 0.77
    0.95917797088623 0.772
    0.9609375 0.774
    0.961094856262207 0.776
    0.963354587554932 0.778
    0.965522766113281 0.78
    0.965757369995117 0.782
    0.967076301574707 0.784
    0.967202425003052 0.786
    0.967545509338379 0.788
    0.968223810195923 0.79
    0.969933986663818 0.792
    0.971006393432617 0.794
    0.973240852355957 0.796
    0.973927021026611 0.798
    0.975241422653198 0.8
    0.976113557815552 0.802
    0.976897239685059 0.804
    0.978722333908081 0.806
    0.979322195053101 0.808
    0.979899406433105 0.81
    0.980595588684082 0.812
    0.981065273284912 0.814
    0.98111629486084 0.816
    0.981565475463867 0.818
    0.981712341308594 0.82
    0.981823921203613 0.822
    0.982118844985962 0.824
    0.982428789138794 0.826
    0.982529640197754 0.828
    0.983104228973389 0.83
    0.984070539474487 0.832
    0.984326839447021 0.834
    0.985526084899902 0.836
    0.985758304595947 0.838
    0.985928535461426 0.84
    0.986589431762695 0.842
    0.986757278442383 0.844
    0.987012147903442 0.846
    0.987447738647461 0.848
    0.987652778625488 0.85
    0.987669229507446 0.852
    0.987851858139038 0.854
    0.988073587417603 0.856
    0.988127708435059 0.858
    0.988393306732178 0.86
    0.989337921142578 0.862
    0.989368200302124 0.864
    0.989511013031006 0.866
    0.990571975708008 0.868
    0.99067211151123 0.87
    0.991130352020264 0.872
    0.991298675537109 0.874
    0.991401433944702 0.876
    0.992657661437988 0.878
    0.992878913879395 0.88
    0.992885589599609 0.882
    0.993171215057373 0.884
    0.993453025817871 0.886
    0.993632555007935 0.888
    0.994110107421875 0.89
    0.99412202835083 0.892
    0.99418568611145 0.894
    0.99420690536499 0.896
    0.994498014450073 0.898
    0.994644165039062 0.9
    0.994815587997437 0.902
    0.995519638061523 0.904
    0.995697975158691 0.906
    0.995849609375 0.908
    0.995936632156372 0.91
    0.995988845825195 0.912
    0.996234655380249 0.914
    0.996370315551758 0.916
    0.996707916259766 0.918
    0.996789932250977 0.92
    0.997049331665039 0.922
    0.997123718261719 0.924
    0.997220277786255 0.926
    0.997337341308594 0.928
    0.99834942817688 0.93
    0.99862265586853 0.932
    0.998816967010498 0.934
    0.999244451522827 0.936
    0.9994797706604 0.938
    0.999504566192627 0.94
    0.999571084976196 0.942
    0.999622106552124 0.944
    0.99963116645813 0.946
    0.999638855457306 0.948
    0.999679803848267 0.95
    0.999722003936768 0.952
    0.999753475189209 0.954
    0.999823808670044 0.956
    0.999860286712646 0.958
    0.999910354614258 0.96
    0.999917268753052 0.962
    0.999936103820801 0.964
    0.999940872192383 0.966
    0.999940872192383 0.968
    0.999944925308228 0.97
    0.999947547912598 0.972
    0.999955177307129 0.974
    0.999975442886353 0.976
    1.00000238418579 0.978
    1.00005745887756 0.98
    1.00013852119446 0.982
    1.00016021728516 0.984
    1.00020122528076 0.986
    1.00020480155945 0.988
    1.00020837783813 0.99
    1.00020837783813 0.992
    1.00030517578125 0.994
    1.00033760070801 0.996
    1.00033760070801 0.998
    1.00049138069153 1
    };
    \addlegendentry{Successful Adversary}
    \addplot [thick, cyan, const plot mark left, mark=diamond*, mark size=3, mark options={solid}]
    table {%
    -inf 0
    -1.00036525726318 0.002
    -0.999919891357422 0.004
    -0.998908042907715 0.006
    -0.998538970947266 0.008
    -0.998523235321045 0.01
    -0.998489856719971 0.012
    -0.997961044311523 0.014
    -0.997459411621094 0.016
    -0.997300386428833 0.018
    -0.997185468673706 0.02
    -0.997170209884644 0.022
    -0.996307373046875 0.024
    -0.995509624481201 0.026
    -0.995281934738159 0.028
    -0.995051145553589 0.03
    -0.994012832641602 0.032
    -0.993898391723633 0.034
    -0.993505477905273 0.036
    -0.993452072143555 0.038
    -0.992518424987793 0.04
    -0.992339134216309 0.042
    -0.992122173309326 0.044
    -0.991596698760986 0.046
    -0.990509748458862 0.048
    -0.9904625415802 0.05
    -0.987960577011108 0.052
    -0.987029075622559 0.054
    -0.986441612243652 0.056
    -0.985931158065796 0.058
    -0.985378623008728 0.06
    -0.981778860092163 0.062
    -0.981433868408203 0.064
    -0.980193376541138 0.066
    -0.97851037979126 0.068
    -0.975795030593872 0.07
    -0.975239038467407 0.072
    -0.970128297805786 0.074
    -0.966488838195801 0.076
    -0.966117382049561 0.078
    -0.962469696998596 0.08
    -0.946107625961304 0.082
    -0.938248634338379 0.084
    -0.877745628356934 0.086
    -0.573551893234253 0.088
    -0.28668487071991 0.09
    -0.0994682312011719 0.092
    -0.0570862293243408 0.094
    0.110604286193848 0.096
    0.146585941314697 0.098
    0.19149112701416 0.1
    0.353097200393677 0.102
    0.447607040405273 0.104
    0.554367780685425 0.106
    0.559674263000488 0.108
    0.566117167472839 0.11
    0.66569846868515 0.112
    0.712010324001312 0.114
    0.736081123352051 0.116
    0.737093567848206 0.118
    0.753191947937012 0.12
    0.774054110050201 0.122
    0.786118745803833 0.124
    0.803542017936707 0.126
    0.811514139175415 0.128
    0.828089594841003 0.13
    0.828140735626221 0.132
    0.832363843917847 0.134
    0.846338510513306 0.136
    0.883927702903748 0.138
    0.903908491134644 0.14
    0.906551361083984 0.142
    0.912223815917969 0.144
    0.917126893997192 0.146
    0.922109603881836 0.148
    0.922157764434814 0.15
    0.925298690795898 0.152
    0.932986736297607 0.154
    0.934787750244141 0.156
    0.937933802604675 0.158
    0.941241383552551 0.16
    0.941879987716675 0.162
    0.943810820579529 0.164
    0.944938182830811 0.166
    0.945703029632568 0.168
    0.946968793869019 0.17
    0.947619557380676 0.172
    0.948470592498779 0.174
    0.950923919677734 0.176
    0.954836368560791 0.178
    0.957955837249756 0.18
    0.958532094955444 0.182
    0.958635807037354 0.184
    0.958703756332397 0.186
    0.95917797088623 0.188
    0.959328413009644 0.19
    0.9609375 0.192
    0.963263750076294 0.194
    0.963731288909912 0.196
    0.964875221252441 0.198
    0.965044021606445 0.2
    0.965522766113281 0.202
    0.967076301574707 0.204
    0.967202425003052 0.206
    0.967545509338379 0.208
    0.968223810195923 0.21
    0.968503952026367 0.212
    0.968678712844849 0.214
    0.969933986663818 0.216
    0.971124172210693 0.218
    0.971301794052124 0.22
    0.971466302871704 0.222
    0.971677780151367 0.224
    0.972031116485596 0.226
    0.972327709197998 0.228
    0.972474098205566 0.23
    0.973240852355957 0.232
    0.973604440689087 0.234
    0.973893642425537 0.236
    0.974741458892822 0.238
    0.975469589233398 0.24
    0.976009845733643 0.242
    0.976113557815552 0.244
    0.976119995117188 0.246
    0.97648811340332 0.248
    0.976897239685059 0.25
    0.976909399032593 0.252
    0.977321147918701 0.254
    0.977556467056274 0.256
    0.978353023529053 0.258
    0.978811740875244 0.26
    0.979099273681641 0.262
    0.979322195053101 0.264
    0.980274438858032 0.266
    0.980324983596802 0.268
    0.980637788772583 0.27
    0.980868577957153 0.272
    0.981065273284912 0.274
    0.981187343597412 0.276
    0.981221914291382 0.278
    0.981231689453125 0.28
    0.981621503829956 0.282
    0.981823921203613 0.284
    0.981841087341309 0.286
    0.982316493988037 0.288
    0.982428789138794 0.29
    0.982728958129883 0.292
    0.982906341552734 0.294
    0.983031511306763 0.296
    0.983090400695801 0.298
    0.983333587646484 0.3
    0.983745574951172 0.302
    0.983848810195923 0.304
    0.984006643295288 0.306
    0.984232664108276 0.308
    0.984326839447021 0.31
    0.984326839447021 0.312
    0.98456335067749 0.314
    0.984737396240234 0.316
    0.984760284423828 0.318
    0.985237121582031 0.32
    0.985323429107666 0.322
    0.985458374023438 0.324
    0.98551607131958 0.326
    0.985526084899902 0.328
    0.985607862472534 0.33
    0.985611438751221 0.332
    0.985635280609131 0.334
    0.985737800598145 0.336
    0.985758304595947 0.338
    0.985873699188232 0.34
    0.985976219177246 0.342
    0.98603630065918 0.344
    0.986340045928955 0.346
    0.986439228057861 0.348
    0.986474514007568 0.35
    0.986586332321167 0.352
    0.986589431762695 0.354
    0.986968278884888 0.356
    0.987360954284668 0.358
    0.987436294555664 0.36
    0.987441539764404 0.362
    0.987447738647461 0.364
    0.987518072128296 0.366
    0.987655162811279 0.368
    0.987669229507446 0.37
    0.988032341003418 0.372
    0.988127708435059 0.374
    0.988154411315918 0.376
    0.988163232803345 0.378
    0.988173723220825 0.38
    0.98820686340332 0.382
    0.988393306732178 0.384
    0.988569736480713 0.386
    0.988698482513428 0.388
    0.988733530044556 0.39
    0.988761425018311 0.392
    0.988884687423706 0.394
    0.988990306854248 0.396
    0.989216327667236 0.398
    0.98923659324646 0.4
    0.989455699920654 0.402
    0.989529132843018 0.404
    0.989707946777344 0.406
    0.990255117416382 0.408
    0.990348339080811 0.41
    0.990427732467651 0.412
    0.990468263626099 0.414
    0.990573883056641 0.416
    0.990585327148438 0.418
    0.99067211151123 0.42
    0.990678787231445 0.422
    0.99078369140625 0.424
    0.990891456604004 0.426
    0.991001129150391 0.428
    0.991231918334961 0.43
    0.991256475448608 0.432
    0.991401433944702 0.434
    0.991454839706421 0.436
    0.991459369659424 0.438
    0.99160099029541 0.44
    0.991647720336914 0.442
    0.991694927215576 0.444
    0.991765975952148 0.446
    0.991803884506226 0.448
    0.992069721221924 0.45
    0.992573738098145 0.452
    0.992657661437988 0.454
    0.992786407470703 0.456
    0.992878913879395 0.458
    0.992885589599609 0.46
    0.993107318878174 0.462
    0.993184328079224 0.464
    0.993188858032227 0.466
    0.993249177932739 0.468
    0.993272066116333 0.47
    0.993437528610229 0.472
    0.993453025817871 0.474
    0.99345588684082 0.476
    0.993529796600342 0.478
    0.993610382080078 0.48
    0.993632555007935 0.482
    0.993632555007935 0.484
    0.993666887283325 0.486
    0.993668794631958 0.488
    0.993866443634033 0.49
    0.99400520324707 0.492
    0.994046211242676 0.494
    0.994110107421875 0.496
    0.99412202835083 0.498
    0.994208335876465 0.5
    0.994258880615234 0.502
    0.994269609451294 0.504
    0.994408130645752 0.506
    0.994465827941895 0.508
    0.994569063186646 0.51
    0.994593620300293 0.512
    0.994613647460938 0.514
    0.994644165039062 0.516
    0.994731903076172 0.518
    0.9947350025177 0.52
    0.994856834411621 0.522
    0.994903087615967 0.524
    0.994988679885864 0.526
    0.99503231048584 0.528
    0.995033264160156 0.53
    0.995339155197144 0.532
    0.99548602104187 0.534
    0.99549388885498 0.536
    0.995519638061523 0.538
    0.995543479919434 0.54
    0.995632886886597 0.542
    0.995761394500732 0.544
    0.99576735496521 0.546
    0.995849609375 0.548
    0.995916843414307 0.55
    0.995932102203369 0.552
    0.99596118927002 0.554
    0.996238231658936 0.556
    0.996238231658936 0.558
    0.996279954910278 0.56
    0.996335506439209 0.562
    0.996359825134277 0.564
    0.996370315551758 0.566
    0.996415138244629 0.568
    0.996492385864258 0.57
    0.996516227722168 0.572
    0.996617078781128 0.574
    0.996709823608398 0.576
    0.996840000152588 0.578
    0.996963024139404 0.58
    0.997032165527344 0.582
    0.997166156768799 0.584
    0.997220277786255 0.586
    0.997240304946899 0.588
    0.997317790985107 0.59
    0.997337341308594 0.592
    0.997524976730347 0.594
    0.99754810333252 0.596
    0.997587203979492 0.598
    0.997612714767456 0.6
    0.997700691223145 0.602
    0.998099088668823 0.604
    0.998206615447998 0.606
    0.998254776000977 0.608
    0.998332262039185 0.61
    0.998445510864258 0.612
    0.998459815979004 0.614
    0.998472929000854 0.616
    0.998505115509033 0.618
    0.998590469360352 0.62
    0.99862265586853 0.622
    0.998676776885986 0.624
    0.998757362365723 0.626
    0.998800754547119 0.628
    0.998837471008301 0.63
    0.998838424682617 0.632
    0.998901844024658 0.634
    0.998944759368896 0.636
    0.999152898788452 0.638
    0.999155044555664 0.64
    0.999231815338135 0.642
    0.999354362487793 0.644
    0.99938440322876 0.646
    0.999392032623291 0.648
    0.999408960342407 0.65
    0.999452590942383 0.652
    0.99945592880249 0.654
    0.999456644058228 0.656
    0.999456644058228 0.658
    0.999478578567505 0.66
    0.999497652053833 0.662
    0.999502182006836 0.664
    0.999504566192627 0.666
    0.999523639678955 0.668
    0.999527454376221 0.67
    0.999551057815552 0.672
    0.999563217163086 0.674
    0.999571084976196 0.676
    0.999572515487671 0.678
    0.999576091766357 0.68
    0.999601364135742 0.682
    0.999607086181641 0.684
    0.999611377716064 0.686
    0.999612331390381 0.688
    0.999622106552124 0.69
    0.999629735946655 0.692
    0.999630451202393 0.694
    0.99963116645813 0.696
    0.999636650085449 0.698
    0.999636650085449 0.7
    0.999637603759766 0.702
    0.999638855457306 0.704
    0.999649286270142 0.706
    0.999658584594727 0.708
    0.999659061431885 0.71
    0.999659538269043 0.712
    0.999661684036255 0.714
    0.999667167663574 0.716
    0.999669551849365 0.718
    0.999678134918213 0.72
    0.999678611755371 0.722
    0.999679803848267 0.724
    0.999688148498535 0.726
    0.999695301055908 0.728
    0.999697923660278 0.73
    0.999699354171753 0.732
    0.999703645706177 0.734
    0.999703884124756 0.736
    0.999714136123657 0.738
    0.99971604347229 0.74
    0.999716520309448 0.742
    0.999717473983765 0.744
    0.999729156494141 0.746
    0.999740123748779 0.748
    0.999740362167358 0.75
    0.999742984771729 0.752
    0.999752283096313 0.754
    0.999753475189209 0.756
    0.999755859375 0.758
    0.999760150909424 0.76
    0.99976921081543 0.762
    0.999775886535645 0.764
    0.999778747558594 0.766
    0.999786376953125 0.768
    0.999790668487549 0.77
    0.999796390533447 0.772
    0.999804019927979 0.774
    0.999804496765137 0.776
    0.999809265136719 0.778
    0.999819278717041 0.78
    0.999828338623047 0.782
    0.999829769134521 0.784
    0.999831676483154 0.786
    0.999832630157471 0.788
    0.999833345413208 0.79
    0.999833345413208 0.792
    0.999834060668945 0.794
    0.999834060668945 0.796
    0.999853134155273 0.798
    0.999853372573853 0.8
    0.999856948852539 0.802
    0.999860286712646 0.804
    0.999860525131226 0.806
    0.999861240386963 0.808
    0.999861240386963 0.81
    0.999863624572754 0.812
    0.999868392944336 0.814
    0.999869585037231 0.816
    0.999871492385864 0.818
    0.999874353408813 0.82
    0.999877214431763 0.822
    0.999878406524658 0.824
    0.99988579750061 0.826
    0.99988865852356 0.828
    0.999889373779297 0.83
    0.99989652633667 0.832
    0.999900817871094 0.834
    0.999917030334473 0.836
    0.999917268753052 0.838
    0.999923706054688 0.84
    0.999929189682007 0.842
    0.999937534332275 0.844
    0.99993896484375 0.846
    0.999940872192383 0.848
    0.999949216842651 0.85
    0.999953508377075 0.852
    0.999955177307129 0.854
    0.999956846237183 0.856
    0.999959707260132 0.858
    0.999963283538818 0.86
    0.999975442886353 0.862
    0.999986410140991 0.864
    1.00000143051147 0.866
    1.00000238418579 0.868
    1.00000238418579 0.87
    1.00000238418579 0.872
    1.00001311302185 0.874
    1.00001549720764 0.876
    1.00002264976501 0.878
    1.00002694129944 0.88
    1.00003051757812 0.882
    1.00003051757812 0.884
    1.00003838539124 0.886
    1.00004005432129 0.888
    1.00004053115845 0.89
    1.00004243850708 0.892
    1.00005292892456 0.894
    1.00006580352783 0.896
    1.00006699562073 0.898
    1.00007057189941 0.9
    1.00007843971252 0.902
    1.00010275840759 0.904
    1.00010657310486 0.906
    1.00010776519775 0.908
    1.00011301040649 0.91
    1.00011539459229 0.912
    1.00011825561523 0.914
    1.00012278556824 0.916
    1.00013709068298 0.918
    1.00013995170593 0.92
    1.00014305114746 0.922
    1.00015020370483 0.924
    1.00015616416931 0.926
    1.00016140937805 0.928
    1.00016617774963 0.93
    1.00017786026001 0.932
    1.00018215179443 0.934
    1.0001859664917 0.936
    1.00018668174744 0.938
    1.00018692016602 0.94
    1.00019145011902 0.942
    1.00020051002502 0.944
    1.00020122528076 0.946
    1.00020480155945 0.948
    1.00020837783813 0.95
    1.00021553039551 0.952
    1.00021648406982 0.954
    1.00021815299988 0.956
    1.00022172927856 0.958
    1.00022387504578 0.96
    1.00022745132446 0.962
    1.00022745132446 0.964
    1.00022745132446 0.966
    1.00023221969604 0.968
    1.00023984909058 0.97
    1.00024247169495 0.972
    1.00028562545776 0.974
    1.00028562545776 0.976
    1.00028944015503 0.978
    1.00030517578125 0.98
    1.00031137466431 0.982
    1.00032925605774 0.984
    1.00033760070801 0.986
    1.00033760070801 0.988
    1.00036573410034 0.99
    1.00038957595825 0.992
    1.00047159194946 0.994
    1.00047159194946 0.996
    1.00049138069153 0.998
    1.00051140785217 1
    };
    \addlegendentry{Repaired Adversary}
    \end{axis}
    
    \end{tikzpicture}
    
    """

    style_settings = {
        "legend pos": "north west",
        'legend entries': '{}',
    }
    reformat_tikz_format_for_colalab(tex_src_template,
                                     tex_src_data,
                                     output_path='tikz.tex',
                                     style_settings=style_settings)
